- .recipe_object
The data that you want to process
- ...
One or more selector functions to choose variables to be imputed.
When used with imp_vars, these dots indicate which variables are used to
predict the missing data in each variable. See selections() for more details
- .type_of_scale
This is a quoted argument and can be one of the following:
"boxcox"
"bs"
"log"
"logit"
"ns"
"relu"
"sqrt"
"yeojohnson
- .bc_limits
A length 2 numeric vector defining the range to compute the
transformation parameter lambda.
- .bc_num_unique
An integer to specify minimum required unique values to
evaluate for a transformation
- .bs_deg_free
The degrees of freedom for the spline. As the degrees of
freedom for a spline increase, more flexible and complex curves can be
generated. When a single degree of freedom is used, the result is a rescaled
version of the original data.
- .bs_degree
Degree of polynomial spline (integer).
- .log_base
A numberic value for the base.
- .log_offset
An optional value to add to the data prior to logging (to avoid log(0))
- .logit_offset
A numberic value to modify values ofthe columns that are
either one or zero. They are modifed to be x - offset or offset respectively.
- .ns_deg_free
The degrees of freedom for the natural spline. As the
degrees of freedom for a natural spline increase, more flexible and complex
curves can be generated. When a single degree of freedom is used, the result
is a rescaled version of the original data.
- .rel_shift
A numeric value dictating a translation to apply to the data.
- .rel_reverse
A logical to indicate if theleft hinge should be used as
opposed to the right hinge.
- .rel_smooth
A logical indicating if hte softplus function, a smooth
approximation to the rectified linear transformation, should be used.
- .yj_limits
A length 2 numeric vector defining the range to compute the
transformation parameter lambda.
- .yj_num_unique
An integer where data that have less possible values
will not be evaluated for a transformation.